# History

## 0.1.5 (2024-10-04)
- **FIX:** Versioning issue resolved. ({pull}`13`) by [@syedhamidali](https://github.com/syedhamidali)

## 0.1.4 (2024-10-04)
- **ENH:** Added environment `.yml` file. ({pull}`2`) by [@syedhamidali](https://github.com/syedhamidali)
- **ADD:** Links.rst added in docs. ({pull}`3`) by [@syedhamidali](https://github.com/syedhamidali)
- **FIX:** Fixed HTML title issue. ({pull}`4`) by [@syedhamidali](https://github.com/syedhamidali)
- **ENH:** Updated `README.md`. ({pull}`5`) by [@syedhamidali](https://github.com/syedhamidali)
- **FIX:** Addressed versioneer issues. ({pull}`6`, {pull}`7`) by [@syedhamidali](https://github.com/syedhamidali)
- **FIX:** Updated radarx logo. ({pull}`8`) by [@syedhamidali](https://github.com/syedhamidali)
- **MNT:** Converted RST to MD in documentation. ({pull}`10`) by [@syedhamidali](https://github.com/syedhamidali)
- **FIX:** history.md updates. ({pull}`11`) by [@syedhamidali](https://github.com/syedhamidali)
- **ADD:** Added logo to `README.md`. ({pull}`12`) by [@syedhamidali](https://github.com/syedhamidali)

## 0.1.3 (2024-10-03)
- **ENH:** Added environment `.yml` file. ({pull}`2`) by [@syedhamidali](https://github.com/syedhamidali)
- **ADD:** Added `Links.rst` in docs. ({pull}`3`) by [@syedhamidali](https://github.com/syedhamidali)
- **FIX:** Fixed HTML title issue. ({pull}`4`) by [@syedhamidali](https://github.com/syedhamidali)
- **ENH:** Updated `README.md`. ({pull}`5`) by [@syedhamidali](https://github.com/syedhamidali)
- **FIX:** Addressed versioneer issues. ({pull}`6`, {pull}`7`) by [@syedhamidali](https://github.com/syedhamidali)
- **FIX:** Updated radarx logo. ({pull}`8`) by [@syedhamidali](https://github.com/syedhamidali)
- **MNT:** Converted RST to MD in documentation. ({pull}`10`) by [@syedhamidali](https://github.com/syedhamidali)
- **FIX:** history.md updates. ({pull}`11`) by [@syedhamidali](https://github.com/syedhamidali)
- **ADD:** Added logo to `README.md`. ({pull}`12`) by [@syedhamidali](https://github.com/syedhamidali)

## 0.1.2 (2024-10-02)
- **FIX:** Created issue template. ({pull}`1`) by [@syedhamidali](https://github.com/syedhamidali)

## 0.1.1 (2024-10-01)
- Initial enhancements and setup completed.
- Full changelog: v0.1.0...v0.1.1

## 0.1.0 (2024-09-30)
- First commit and setup with pre-commit hooks.
